<?php

###############################################################################
# turkish.php
# This is the turkish language page for Geeklog 1.4.0
# Translated by Kemal CELLAT
# kemal@moderntalking.biz
# http://www.moderntalking.biz
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# - root (user)
###############################################################################

$LANG_CHARSET = 'iso-8859-9';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => 'Ekleyen:',
    2 => 'devam',
    3 => 'yorum',
    4 => 'Deitir',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => 'Ynetici kontrolleri:',
    10 => 'Gnderilenler',
    11 => 'Yazlar',
    12 => 'Bloklar',
    13 => 'Konular',
    14 => '',
    15 => '',
    16 => '',
    17 => 'Kullanclar',
    18 => 'SQL Sorgusu',
    19 => 'Sistemden k',
    20 => 'Kullanc Bilgileri:',
    21 => 'Kullanc Ad',
    22 => 'Kullanc Tanmlaycs',
    23 => 'Gvenlik Seviyesi',
    24 => 'simsiz Kullanc',
    25 => 'Yorum Ekle',
    26 => 'Aadaki yorumlarn sorumluluu gnderene aittir. Sitemiz herhangi bir sorumluluk kabul etmez.',
    27 => 'En Son',
    28 => 'Sil',
    29 => 'Hi yorum yaplmam.',
    30 => 'Eski Yazlar',
    31 => 'Kabul edilen HTML komutlar:',
    32 => 'Kullanc adnz yanl',
    33 => 'Hata, kayt dosyasna yazlamyor',
    34 => 'Hata',
    35 => 'k Yap',
    36 => 'on',
    37 => 'Kullanclardan hi bir yaz gelmemi',
    38 => 'Content Syndication',
    39 => 'Yenile',
    40 => '',
    41 => 'Misafirler',
    42 => 'Yazar:',
    43 => 'Cevap Ver',
    44 => 'st',
    45 => 'MySQL Hata Numaras',
    46 => 'MySQL Hata Mesaj',
    47 => 'Kullanc',
    48 => 'Kayt Bilgileriniz',
    49 => 'Grnm zellikleri',
    50 => 'SQL komutunda hata var',
    51 => 'yardm',
    52 => 'Yeni',
    53 => 'Kontrol Ana Sayfas',
    54 => 'Dosya alamyor.',
    55 => 'Hata',
    56 => 'Oy kullan',
    57 => 'ifre',
    58 => 'Sisteme Gir',
    59 => "Hala ye deilmisiniz?<br" . XHTML . "><a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">ye olun</a>",
    60 => 'Yorum Gnder',
    61 => 'Yeni ',
    62 => 'kelime',
    63 => 'Yorum Ayarlar',
    64 => 'Bu Yazy bir Arkadana Gnder',
    65 => 'Baslabilir Hali',
    66 => '',
    67 => 'Ho Geldiniz',
    68 => 'Ana Sayfa',
    69 => 'iletiim',
    70 => 'ara',
    71 => 'yaz ekle',
    72 => 'web kaynaklar',
    73 => '',
    74 => '',
    75 => 'gelimi arama',
    76 => 'site istatistikleri',
    77 => 'Eklentiler',
    78 => '',
    79 => 'Yenilikler',
    80 => 'hikaye son',
    81 => 'hikaye son',
    82 => 'saat',
    83 => 'YORUMLAR',
    84 => '',
    85 => 'son 48 saat',
    86 => 'Hi yeni yorum yok',
    87 => 'son 2 hafta',
    88 => '',
    89 => '',
    90 => 'Ana Sayfa',
    91 => 'Yaratlma sresi:',
    92 => 'saniye',
    93 => 'Copyright',
    94 => 'Bu sayfalarda yaymlanan materyalin tm haklar sahiplerine aittir.',
    95 => 'Powered by:',
    96 => 'Gruplar',
    97 => 'Kelime Listesi',
    98 => 'Eklentiler',
    99 => 'Yazlar',
    100 => 'Hi yeni yaz yok',
    101 => '',
    102 => '',
    103 => 'Veritaban Yedekleri',
    104 => 'ta. Gnderen:',
    105 => 'Kullanclara Mesaj',
    106 => 'Okunma',
    107 => 'GL Srm Testi',
    108 => 'nbellei Temizle',
    109 => 'Uygunsuz ierik',
    110 => 'Bu iletiyi site adminine bildirin',
    111 => '',
    112 => 'Kaytl yeler',
    113 => 'Dkmantasyon',
    114 => 'TRACKBACKS',
    115 => 'Yeni trackback iletisi yok',
    116 => 'Trackback',
    117 => 'Dizin',
    118 => 'Ltfen sradaki sayfay okuyunuz:',
    119 => "ifrenizi mi <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\">unuttunuz</a>?",
    120 => 'Permanent link to this comment',
    121 => 'Yorumlar (%d)',
    122 => 'Trackbacks (%d)',
    123 => 'Tm HTML kodlar izinli',
    124 => 'Seili tm eleri Silmek iin Tklayn',
    125 => 'Seili tm eleri silmek istediinize emin misiniz?',
    126 => 'Tm eleri aretle veya iareti kaldr ',
    127 => 'Permalink',
    128 => 'Login with OpenID:',
    129 => 'Configuration',
    130 => 'Webservices',
    131 => 'No HTML is allowed',
    132 => 'Information',
    133 => 'Critical',
    134 => 'Help',
    135 => 'Warning',
    136 => 'Warning: Javascript recommended for enhanced functionality',
    137 => 'Warning: Javascript required to enable functionality',
    138 => "Click <a href=\"{$_CONF['site_url']}/usersettings.php\" rel=\"nofollow\">here</a> to disable the advanced editor and use the default editor which does not require JavaScript",
    139 => "Click <a href=\"{$_CONF['site_url']}/\" rel=\"nofollow\">here</a> to return to the homepage"
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => 'Yorum ekle',
    2 => 'Biim Methodu',
    3 => 'Sistemden k',
    4 => 'Sisteme ye ol',
    5 => 'Kullanc Ad',
    6 => 'Yorum koyabilmeniz iin sisteme giri yapmanz gerekiyor. Eer bir kullanc adnz yoksa aadaki formu kullanarak kendinize bir tane yaratn.',
    7 => 'Son yorumunuz ',
    8 => " saniye nceydi.  Bu sitede iki yorum arasnda minimum {$_CONF['commentspeedlimit']} saniye olmaldr.",
    9 => 'Yorum',
    10 => 'Rapor Et',
    11 => 'Yorumu Ekle',
    12 => 'Ltfen Balk ve Yorum bloklarn doldurunuz.',
    13 => 'Bilgileriniz',
    14 => 'n zleme',
    15 => 'Bu iletiyi Rapor Et',
    16 => 'Balk',
    17 => 'Hata',
    18 => 'nemli Bilgiler',
    19 => 'Yorumlarnzn konuyla ilgili olmasna dikkat ediniz.',
    20 => 'Yeni bir yorum bal amaktansa baka insanlarn yorumlarna cevap vermeyi tercih ediniz.',
    21 => 'Baka insanlarn yorumlarn okuyunuz ki ayn eyleri bir de siz sylememi olun.',
    22 => 'Yorumunuzun konusunu ieriini iyi anlatan bir ekilde seiniz.',
    23 => 'Email adresiniz dier kullanclara GSTERLMEYECEKTR.',
    24 => 'Herhangi Kullanc',
    25 => 'Bu iletiyi site adminine bildirmek istediinize emin misiniz?',
    26 => '%s Bu ileti site adminine bildirilmitir:',
    27 => 'ikayet Et',
    28 => 'Preview Changes',
    29 => 'Submit Changes',
    30 => 'Edited on',
    31 => 'by',
    32 => 'Editing a Comment',
    33 => 'Editing a Comment Submission',
    34 => 'Preview Submission Changes',
    35 => 'Save Changes to Queue',
    36 => 'Notify me of new replies',
    37 => 'New Comment Reply',
    38 => 'A reply has been made to your comment \'%s\'.',
    39 => 'You may view the comment thread at the following address:',
    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
    41 => 'Hello %s,',
    42 => 'Unsubscribe',
    43 => 'Unsubscribe from reply notifications',
    44 => 'Your Name'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => 'Kullanc Profili:',
    2 => 'Kullanc Ad',
    3 => 'Gerek Ad',
    4 => 'ifre',
    5 => 'Email',
    6 => 'Web Sitesi',
    7 => 'Hakknda',
    8 => 'PGP Anahtar',
    9 => 'Kaydet',
    10 => 'Bu kullanc iin son 10 yorum -',
    11 => 'Hi Yorum Yok',
    12 => 'Kullanc zellikleri:',
    13 => 'Her Gece zet Email',
    14 => 'Bu ifre rastgele yatarlmtr. Bu ifreyi olabildiince abuk deitirmeniz nerilir. ifrenizi deitirmek iin sisteme giri yapp Kullanc mensnden Kayt Bilgilerine gidiniz.',
    15 => "{$_CONF['site_name']} sitesindeki kullanc hesabnz baaryla yaratld. Bu hesab kullanmak iin sitemize aadaki bilgiler dahilinde giri yapnz. Bu maili ileride referans olarak kullanmak iin kaydediniz.",
    16 => 'Kullanc Hesap Bilgileriniz',
    17 => 'Hesap yok',
    18 => 'Belirttiiniz email adresi gerek bir email adresine benzemiyor',
    19 => 'Kullanc adnz veye email adresiniz sistemde kullanlyor',
    20 => 'Belirttiiniz email adresi gerek bir email adresine benzemiyor',
    21 => 'Hata',
    22 => "{$_CONF['site_name']} ye ol!",
    23 => "Bir kullanc hesab yaratmanz size {$_CONF['site_name']} yelii salar. Bu sayede siteye kendinize ait yorumlarnz gnderebilir ve kendi ieriinizi dzenleyebilirsiniz. Eer kullanc hesabnz yoksa sadece Herhangi Birisi-simsiz Kullanc olarak ierik ve yorum gnderebilirsiniz. Sistemimize verdiiniz email adresi <b><i>hi bir zaman</i></b> sitede grntlenmeyecektir.",
    24 => 'ifreniz verdiiniz email adresinize gnderilecektir.',
    25 => 'ifrenizi mi unuttunuz?',
    26 => 'Kullanc adnz girin ve ifremi Gnder tuuna basn. Yeni yaratlacak bir ifre sistemimize kaytl olan email adresinize gnderilecektir.',
    27 => 'ye Ol!',
    28 => 'ifremi Gnder',
    29 => 'Sistemden ktnz:',
    30 => 'Sisteme girdiniz:',
    31 => 'Setiini bu kontrol sisteme giri yapm olmanz gerektirmektedir',
    32 => 'mza',
    33 => 'Site misafirlerine asla gsterilmeyecektir',
    34 => 'Adnz ve soyadnz',
    35 => 'ifrenizi deitirmek iin',
    36 => 'http:// ile balamal',
    37 => 'Yorumlarnza uygulanr',
    38 => 'Hakknzla ilgili herey! Herkes bunu okuyabilir',
    39 => 'Paylaacanz PGP anahtarnz',
    40 => 'Konu Sembol Kullanma',
    41 => 'Ynetime Katlmak stiyorum',
    42 => 'Tarih Biimi',
    43 => 'En Fazla Yaz Says',
    44 => 'Bloklar Olmasn',
    45 => 'Grnm zellikleri -',
    46 => 'Grmek stemediiniz Konu ve Yazarlar -',
    47 => 'Haber Ayarlar -',
    48 => 'Konular',
    49 => 'Yazlarda semboller kullanlmayacak',
    50 => 'lgilenmiyorsanz iareti kaldrn',
    51 => 'Sadece haberler ile ilgili yazlar',
    52 => 'Varsaylan:',
    53 => 'Gnn yazlarn her akam al',
    54 => 'Grmek istemediiniz konu ve kullanclar ile ilgili seenekleri seiniz.',
    55 => 'Site tarafndan varsaylan seim deerlerini kullanmak istiyorsanz, seeneklerin tamamn bo brakrsanz. Eer herhangi bir seim yaparsanz, varsaylan seimler kullanlmaz, bu yzden grmek istediiniz tm zellikleri semeniz gerekir. Varsaylan seimler kaln yaz tipi ile belirtilmitir.',
    56 => 'Yazarlar',
    57 => 'Grnm ekli',
    58 => 'Sralama ekli',
    59 => 'Yorum Says Limiti',
    60 => 'Yorumlarnzn nasl grntlenmesini istersiniz?',
    61 => 'lk en yeni mi, yoksa en eski mi gsterilsin?',
    62 => 'Varsaylan deer 100',
    63 => "ifreniz email adresinize gnderildi. Ltfen, email mesajnzda belirtilen admlar uygulayn. {$_CONF['site_name']} kullandnz iin teekkr ederiz!",
    64 => 'Yorum Ayarlar -',
    65 => 'Bir Daha Sisteme Girmeyi Deneyin',
    66 => "Kullanc adnz veya ifrenizi yanl girdiniz. Ltfen aadaki formu kullanarak bir daha sisteme giri yapmay deneyin. <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">Yeni bir kullanc</a> msnz?",
    67 => 'yelik Tarihi',
    68 => 'Beni hatrla:',
    69 => 'Sizi sisteme giri yaptktan sonra hatrlama sresi',
    70 => "{$_CONF['site_name']} iin ierik ve grnm ayarlar dzenleyin",
    71 => "{$_CONF['site_name']} nin en byk zellii, ieriinizi zelletirebilir, bu sitenin tm grntsn deitirebilirsiniz.  Bu byk avantajlardan yararlanmak iin ncelikle {$_CONF['site_name']} ne <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">kayt yapmalsnz</a>.  Zaten kaytl bir yemisiniz?  O zaman sol taraftaki formu kullanarak giri yapnz!",
    72 => 'Tema',
    73 => 'Dil',
    74 => 'Sitenin grnmn deitirin!',
    75 => 'Email ile Gnderilecek Konular -',
    76 => 'If you select a topic from the list below you will receive any new stories posted to that topic at the end of each day.  Choose only the topics that interest you!',
    77 => 'Resim',
    78 => 'Resminizi Ekleyin!',
    79 => 'Resmi silmek iin buray sein',
    80 => 'Siteye Giri',
    81 => 'Email Yolla',
    82 => 'Son 10 Mesaj -',
    83 => 'Yaz gnderme istatistikleri -',
    84 => 'Yazlan yazlarn toplam:',
    85 => 'Yazlan yorumlarn toplam:',
    86 => 'Gnderdii tm mesajlar:',
    87 => 'Giri Adnz',
    88 => "Birisi (belki siz) {$_CONF['site_name']}, sitesindeki \"%s\" hesabnz iin yeni bir ifre istedi <{$_CONF['site_url']}>.\n\nayet siz gerekten bu ifreyi almak istiyorsanz, ltfen bu linki tklayn:\n\n",
    89 => "ayet bu ifreyi almak istemiyorsanz, bu mesaj dikkate almayn ve bu istei nemsemeyin (ifreniz deimeyecek ve olduu gibi kalacaktr).\n\n",
    90 => 'Aadaki hesabnz iin yeni bir ifre girmelisiniz. Not: bu formu gnderinceye kadar eski ifreniz geerlidir.',
    91 => 'Yeni ifre Belirle',
    92 => 'Yeni ifre Gir',
    93 => 'Yeni bir ifre isteiniz %d saniye nceydi. Bu site ifre istekleri arasnda en az %d saniye olmasn aramaktadr.',
    94 => '"%s" isimli yenin Hesabn Sil',
    95 => 'Aadaki "hesab sil" butonuna tklaynca hesabnz, veritabanmzdan kaldrlacaktr. Not, bu hesabnz altnda gnderdiiniz yazlar ve yorumlar <strong>silinmeyecektir</strong> fakat iletiler "simsiz Kullanc" olarak grntlenecektir.',
    96 => 'hesab sil',
    97 => 'Hesap Silme Onay',
    98 => 'Hesabnz silmek istediinize eminmisiniz? Bylece yeni bir hesap yaratncaya kadar bu siteye kaytl kullanc olarak giremeyeceksiniz. ayet eminseniz aadaki formda ki "hesab sil" butonuna tekrar tklaynz.',
    99 => 'isimli yenin Gizlilik Seenekleri',
    100 => 'Yneticiden Email',
    101 => 'Site yneticilerinden email izni',
    102 => 'yelerden Email',
    103 => 'Dier yelerden email izni',
    104 => 'Aktifliinizin Grntlenmesi',
    105 => 'Aktif Kullanclar Blounda grntlenme',
    106 => 'ehir',
    107 => 'Kiisel profilinizde grntlenir',
    108 => 'Yeni ifre tekrar',
    109 => 'Yeni ifrenizi tekrar yazn',
    110 => 'uan ki ifreniz',
    111 => 'Ltfen uan kullanmakta olduunuz ifreyi girin',
    112 => 'zin verilen giri saysn am bulunuyorsunuz.  Ltfen daha sonra tekrar deneyiniz.',
    113 => 'Login Attempt Failed',
    114 => 'Kapal Hesap',
    115 => 'Hesabnz kapatlmtr, uzun sredir diri yapmam olabilirsiniz. Ltfen site admini ile iletiime geiniz.',
    116 => 'Hesabnz Aktivasyon bekliyor',
    117 => 'Hesabnz site ynetimi tarafndan onay beklemektedir. Hesabnz onaylanncaya kadar giri yapmazsnz.',
    118 => "{$_CONF['site_name']}hesabnz site ynetimi tarafndan aktifletirildi. Aaadaki linkten kullanc adnz: (<username>) ve size daha nce gnderilen ifrenizle giri yapabilirsiniz.",
    119 => 'Eer ifrenizi unuttuysanz, bu linkten yeni bir ifre belirleyebilirsiniz:',
    120 => 'Aktif Hesap',
    121 => 'Servis',
    122 => 'zgnm, Yeni Kullanc kayd kapatlmtr',
    123 => "<a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">Yeni ye misiniz?</a>?",
    124 => 'Email Tekrar ',
    125 => 'Girdiiniz E-mail adresleri ayn deil!',
    126 => 'Dorulama iin ltfen tekrar yazn',
    127 => 'Burada ki ayarlardan herhangi birini deitirmek iin ifrenizi girmeniz gerekiyor.',
    128 => 'Adnz',
    129 => 'ifre &amp; Email',
    130 => 'Hakknzda',
    131 => 'Gnlk zet Ayarlar',
    132 => 'Gnlk zet zellii',
    133 => 'Yorum Ekran',
    134 => 'Yorum Ayarlar',
    135 => '<li>Yorumlarnn nasl gsterileceine ait ayarlar</li><li>Yorumlarn sralanma ekline ait ayar</li><li>En fazla gsterilecek yorum says - geerli say 100</li>',
    136 => 'Gsterilmeyecek Konu ve Yazarlar',
    137 => 'Yaz erii Filtreleme',
    138 => 'Dier Ayarlar',
    139 => 'Grnm ve Language',
    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
    141 => 'Eriilebilirlik Ayarlar',
    142 => 'Geerli site ayarlar yelerden ve yneticiden ye almanza izin vermekte ve online kullanlar blounda grnmenize izin vermektedir.Kutuda iareti kaldrarak istemediiniz zellii iptal edebilirsiniz.',
    143 => 'Block erii Filtresi',
    144 => 'Gster & Gizle Bloklar',
    145 => 'Kiisel Profilimi Gster',
    146 => 'ifre ve E-mail',
    147 => 'ifrenizi, emailinizi ve beni hatrla zelliklerini dzenleyin. Dorulama iin ifrenizi veya e-mail adresinizi iki kez girmeniz gerekmektedir.',
    148 => 'Kullanc Bilgileri',
    149 => 'Dier Kullanclarn da grecei kullanc bilgilerinizi dzenleyin.<li>mzanz yorumlarnza ve forumda ki mesajlarnzn altna otomatik olarak eklenir</li><li>Kendiniz hakknda paylamak istediklerinizi BIO blmne yazabilirsiniz</li><li>PGP Anahtar (Bo Brakabilirsiniz)</li>',
    150 => '',
    156 => 'Hesabm Sil',
    157 => 'Delete Option',
    158 => 'Time Zone',
    159 => 'This email was generated automatically. Please do not reply to this email.',
    160 => '(max. %d x %d pixels, %d bytes; %s)',
    161 => 'will be scaled down',
    162 => 'will not be scaled',
    163 => 'Re-Authentication Failed',
    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
    165 => 'Use Advanced Editor',
    166 => 'Re-synch Remote Account'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Preview',
    'pe_namepass' => 'Username &amp; Password',
    'pe_userinfo' => 'About You',
    'pe_layout' => 'Layout &amp; Language',
    'pe_content' => 'Content',
    'pe_privacy' => 'Privacy'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => 'Gsterilecek hi haber yok',
    2 => 'Gsterilecek hi haber yazs yok. Bu konu hakknda hi haber olmayabilir, veya belirlediiniz ayarlar yznden gsterilemiyor olabilir',
    3 => ' %s iin',
    4 => 'Gnn Yazs',
    5 => 'Sonraki',
    6 => 'nceki',
    7 => 'lk',
    8 => 'Son'
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'Mesaj gnderilirken bir hata olutu. Ltfen bir daha deneyin.',
    2 => 'Mesajnz baaryla gnderildi.',
    3 => 'Cevap Adresi alanna doru bir email adresi girdiinizden emin olunuz.',
    4 => 'Ltfen, Adnz, Cevap Adresinizi, Konu ve Mesaj alanlarn doldurunuz',
    5 => 'Hata: Byle bir kullanc yok.',
    6 => 'Hata olutu.',
    7 => 'Kullanc Profili:',
    8 => 'Kullanc Ad',
    9 => 'Kullanc URL\'',
    10 => 'Mail yolla:',
    11 => 'Adnz:',
    12 => 'Cevap Adresi:',
    13 => 'Konu:',
    14 => 'Mesaj:',
    15 => 'HTML kodu evrilmeyecektir.',
    16 => 'Mesaj Gnder',
    17 => 'Bu Yazy bir Arkadana Gnder',
    18 => 'Alcnn Ad',
    19 => 'Alcnn Email Adresi',
    20 => 'Gnderen Ad',
    21 => 'Gnderen Emaili',
    22 => 'Btn alanlar doldurmalsnz',
    23 => "Bu email size %s (%s) tarafndan gnderilmitir. Sizin bu yaz {$_CONF['site_url']} ile ilgilenebileceinizi dnd. Bu bir SPAM deildir, ve sizin email adresiniz herhangi bir ekilde bir listeye eklenmemitir.",
    24 => 'Bu yazya yorum ekle',
    25 => 'Bu zellii kullanabilmeniz iin sisteme giri yapmanz gerekmektedir. Sitemize giri yapmanz sayesinde sitemizin kt kullanmn nlemi olursunuz',
    26 => 'Bu form sizin setiiniz kullancya email yollamanz salar. Tm alanlar mecburidir.',
    27 => 'Mesaj',
    28 => '%s: ',
    29 => "Bu mesaj {$_CONF['site_name']} gnlk zetidir. ",
    30 => ' Gnlk Haber zeti ',
    31 => 'Balk',
    32 => 'Tarih',
    33 => 'Yaznn tamam iin:',
    34 => 'Mesajn Sonu',
    35 => 'zgnz, bu kullanc hi mail almamay tercih etmi.',
    36 => 'Copy:',
    37 => 'Send me a copy of this email',
    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:",
    39 => 'Your last message was ',
    40 => " seconds ago.  This site requires at least {$_CONF['speedlimit']} seconds between sending messages"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => 'Gelimi Arama',
    2 => 'Anahtar Kelimeler',
    3 => 'Konu',
    4 => 'Tamam',
    5 => 'Tipi',
    6 => 'Yazlar',
    7 => 'Yorumlar',
    8 => 'Yazarlar',
    9 => 'Tamam',
    10 => 'Ara',
    11 => 'Arama Sonular',
    12 => 'bulundu',
    13 => 'Arama Sonular: Hi kayt bulunamad',
    14 => 'Arama kriteriniz ile hi kayt bulunamad:',
    15 => 'Ltfen bir daha deneyin.',
    16 => 'Balk',
    17 => 'Tarih',
    18 => 'Yazar',
    19 => "{$_CONF['site_name']} sitesinin veri tabannda btn yazlar ara.",
    20 => 'Tarih',
    21 => '-',
    22 => '(Tarih yaps YYYY-AA-GG)',
    23 => 'Okunma Says',
    24 => '%d adet kayt bulundu',
    25 => 'kayt bulundu. Toplam',
    26 => 'kayt var. Arama sresi',
    27 => 'saniye.',
    28 => 'Aramanz sonucunda herhangi bir yaz veya yorum bulunamad',
    29 => 'Yaz ve Yorum Arama Sonular',
    30 => '',
    31 => 'Bu eklenti herhangi bir sonu dndrmedi',
    32 => '',
    33 => 'URL',
    34 => 'Yer',
    35 => 'Tm Gn',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => 'Arama yapabilmeniz iin en az 3 harften oluan bir arama sorgusu girmeniz gerekmektedir.',
    42 => 'Ltfen YYYY-AA-GG (Yl-Ay-Gn) eklinde dzenlenmi bir tarhi kullannz.',
    43 => 'tam cmle',
    44 => 'btn kelimeler',
    45 => 'herhangi bir kelime',
    46 => 'Sonraki',
    47 => 'nceki',
    48 => 'Yazar',
    49 => 'Tarih',
    50 => 'Hit',
    51 => '',
    52 => 'Konum',
    53 => 'Yaz Sonular',
    54 => 'Yorum Sonular',
    55 => 'ibare',
    56 => 'VE',
    57 => 'YADA',
    58 => 'Daha fazla sonu &gt;&gt;',
    59 => 'Sonular',
    60 => 'sayfa',
    61 => 'Basit Arama',
    62 => '#',
    63 => 'Description',
    64 => 'Showing %1$d - %2$d of %3$d results',
    65 => 'Story',
    66 => 'Comment',
    67 => 'Show %d Results',
    68 => 'Sort By',
    69 => 'Titles Only',
    70 => 'Not available ...',
    71 => 'asc',
    72 => 'desc'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => 'Site statistikleri',
    2 => 'Siteye gelen toplam trafik',
    3 => 'Sitedeki Yazlar(Yorumlar)',
    4 => '',
    5 => '',
    6 => '',
    7 => 'lk 10 Yaz',
    8 => 'Yaz Bal',
    9 => 'Okunma&nbsp;Says',
    10 => 'Sitenizde ya hi yaz yok yada daha hikimse, hibir yazy okumam.',
    11 => 'En ok Yorum Alan 10 Yaz',
    12 => 'Yorum&nbsp;Says',
    13 => 'Sitenizde ya hi yaz yok yada daha hi kimse yazlara yorum yazmam.',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => 'En ok e-mail ile gnderilen 10 Yaz',
    23 => 'Email&nbsp;Says',
    24 => 'Hi kimse sitenizdeki bir yazy bir arkadana gndermemi.',
    25 => 'Top 10 Trackback Commented Stories',
    26 => 'Traback iletisi yok.',
    27 => 'Aktif Kullanc Says',
    28 => '',
    29 => '',
    30 => 'Hitler',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'lgili',
    2 => 'Arkadana Gnder',
    3 => 'Baslmaya Uygun ekli',
    4 => 'Seenekler',
    5 => '',
    6 => 'Subscribe to \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => '%s gnderebilmek iin sisteme bir kullanc olarak giri yapm olmanz gerekiyor.',
    2 => 'Sisteme gir',
    3 => 'Yeni Kullanc',
    4 => '',
    5 => '',
    6 => 'Yaz Ekle',
    7 => 'Sisteme giri yapm olmanz gerekiyor',
    8 => 'Gnder',
    9 => 'Bir bilgi gnderirken, u nerileri dikkate almanz rica ederiz:<ul><li>Btn alanlar doldurmanz mecburidir.<li>Tam ve doru bilgi veriniz<li>nternet Adresi girerken iki kere kontrol ediniz</ul>',
    10 => 'Balk',
    11 => '',
    12 => 'Balang Tarihi',
    13 => 'Biti Tarihi',
    14 => 'Yer',
    15 => 'Aklama',
    16 => '',
    17 => '',
    18 => '',
    19 => 'nce Okuyun',
    20 => '',
    21 => '',
    22 => 'Hata: Bo alanlar var',
    23 => 'Formdaki tm alanlar doldurunuz. Hepsinin doldurulmas gerekmektedir.',
    24 => 'Gnderiniz Kaydedildi',
    25 => '%s gnderiniz baaryla kaydedildi.',
    26 => 'Hz Limiti',
    27 => 'Kullanc Ac',
    28 => 'Konu',
    29 => 'Yaz',
    30 => 'En son gnderiniz ',
    31 => " saniye nceydi. Bu sitede iki gnderi arasnda en az {$_CONF['speedlimit']} saniye gemesi gerekmektedir",
    32 => 'z zleme',
    33 => 'Yaz n zleme',
    34 => 'Sistemden k',
    35 => 'HTML kodlarnn kullanmna izin verilmemektedir',
    36 => 'Gnderi Tipi',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Adres Satr 1',
    45 => 'Adres Satr 2',
    46 => 'ehir',
    47 => 'le',
    48 => 'Posta Kodu',
    49 => '',
    50 => '',
    51 => 'Yer',
    52 => 'Sil',
    53 => 'Hesap Yarat',
    54 => 'Story Introduction',
    55 => 'Story Body'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => 'Sisteme Giri Yapm Olmanz Gerekiyor',
    2 => 'Engellendi! Sisteme Giri Bilgileriniz Yanl',
    3 => 'ifre kullanc iin yanl:',
    4 => 'Kullanc Ad:',
    5 => 'ifre:',
    6 => 'Sitenin ynetim alanlarnda yaplan tm ilemler kaydedilir ve kontrol edilir.<br' . XHTML . '>Bu sayfa sadece yetkili kiiler tarafndan kullanlabilir.',
    7 => 'sisteme giri yap'
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => 'Yetersiz Ynetici Haklar',
    2 => 'Bu blou dzenlemek iin yeterli haklara sahip deilsiniz.',
    3 => 'Blok Dzenleyicisi',
    4 => 'There was a problem reading this feed (see error.log for details).',
    5 => '',
    6 => '',
    7 => 'Tamam',
    8 => 'Blok Gvenlik Seviyesi',
    9 => 'Blok Sras',
    10 => '',
    11 => 'Portal Blok',
    12 => 'Normal Blok',
    13 => 'Portal Blok zellikleri',
    14 => 'RDF Adresi',
    15 => 'Son RDF Deiiklii',
    16 => 'Normal Blok zellikleri',
    17 => 'Blok erii',
    18 => 'Ltfen Blok Bal, Gvenlik Seviyesi ve erik alanlarn doldurunuz.',
    19 => 'Blok Yneticisi',
    20 => '',
    21 => 'Blok Gv. Sev.',
    22 => '',
    23 => 'Blok Sras',
    24 => '',
    25 => 'Bir blou silmek veya deitirmek istiyorsanz, bloun ismine basnz. Yeni bir blok yaratmak iin yukardaki Yeni Blok dmesine basnz.',
    26 => 'Dzenleme Blou',
    27 => 'PHP Blok',
    28 => 'PHP Blok zellikleri',
    29 => 'Blok Fonksiyonu',
    30 => 'Eer bloklarnzdan birinin PHP kodu kullanmasn istiyorsanz, PHP fonksiyonunun adn yukarya giriniz. Fonksiyon adnz "phpblock_" ile balamaldr(rn. phpblock_getweather). Eer bu ekilde balamyorsa, fonkisyonunuz arlmayacaktr. Bunu yapmamzn nedeni, Geeklog srmn deitiren insanlarn sisteme zarar verebilecek fonksiyonlar kullanmalarn nlemek iindir. Fonkisyon adndan sonra bo parantez  "()" koymamaya dikkat edin. Son olarak, tm PHP kodlarnz /path/to/geeklog/system/lib-custom.php dosyasna koymanz neririz. Bu sayede sistemin yeni srmn ykleseniz bile yazdn kiisel PHP kodlar silinmez.',
    31 => 'PHP Blounda hata. %s fonksiyonu yok.',
    32 => 'Hata: Eksik alan(lar)',
    33 => 'Portal Bloklar iin .rdf dosyasna olan adresi girmeniz gerekmektedir.',
    34 => 'PHP Bloklar iin balk ve fonkisyonu girmeniz gerekmektedir.',
    35 => 'Normal bloklar iin balk ve ierii girmeniz gerekmektedir.',
    36 => 'Dzenleme blou iin ierik girmelisiniz',
    37 => 'PHP Blok fonksiyonunun ad uygun deil',
    38 => 'PHP Bloklar iin arlacak fonksiyonlar \'phpblock_\' ile balamaldr (rn. phpblock_getweather). Bu n ek herhangi bir fonksiyonun arlmasn nlemek iindir.',
    39 => 'Kenar',
    40 => 'Sol',
    41 => 'Sa',
    42 => 'Geeklog varsaylan bloklar iin, blok sras ve gvenlik seviyesini girmelisiniz',
    43 => 'Sadece Ana Sayfa',
    44 => '',
    45 => "Eriim hakknz olmayan bir yazya erimek istiyorsunuz. Bu eyleminiz kaytlara eklenmitir. Ltfen <a href=\"{$_CONF['site_admin_url']}/alan.php\">kontrol ana sayfasna geri dnn</a>.",
    46 => 'Yeni Blok',
    47 => '',
    48 => 'Alan Ad',
    49 => ' (boluk kullanlmamal ve tek olmal)',
    50 => 'The Block Name can not be empty',
    51 => 'http:// ile balayn',
    52 => 'Bu alan bo brakrsanz, blok ile ilikili yardm dmesi gsterilmeyecektir',
    53 => 'Kullanma Ak',
    54 => 'Kaydet',
    55 => 'Vazge',
    56 => 'Sil',
    57 => 'Blou Aa Ta',
    58 => 'Blou Yukar Ta',
    59 => 'Blou Saa Ta',
    60 => 'Blou Sola Ta',
    61 => 'Balk Yok',
    62 => 'Yaz Limiti',
    63 => 'Geersiz Blok Bal',
    64 => 'Balnz bo olamaz ve HTML kodu ieremez!',
    65 => 'Sra',
    66 => 'Autotaglar',
    67 => 'Auttag izini iin iaretleyin',
    68 => 'The feed for this portal block is too long to display. Please set a maximum number of articles to import for the block in the block setup screen, or a global maximum in Geeklog Configuration.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => 'nceki Yaz',
    2 => 'Sonraki Yaz',
    3 => 'zellikler',
    4 => 'Gnderi ekli',
    5 => 'Yaz Dzenle',
    6 => 'Sisteme kaytl hi bir yaz bulunmamakta.',
    7 => 'Yazar',
    8 => 'kaydet',
    9 => 'n izleme',
    10 => 'vazge',
    11 => 'sil',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => 'Tarih',
    16 => 'zet',
    17 => 'erik',
    18 => 'Toplam okunma says',
    19 => 'Yorumlar',
    20 => 'Ping',
    21 => 'Ping Gnder',
    22 => 'Yaz Listesi',
    23 => 'Bir yazy deitirmek veya silmek istiyorsanz, yaznn numarasna basnz. Bir yazy grntlemek istiyorsanz, yaznn balna basnz. Yeni bir yaz yaratmak istiyorsanz, yukardaki Yeni Yaz dmesine basnz.',
    24 => 'Setiiniz ID kullanlyor. Ltfen baka bir ID seiniz.',
    25 => 'Yazy kaydederken hata olutu!',
    26 => 'Yaz n zleme',
    27 => 'eer [imageX]yerine [unscaledX] kodunu kullanrsanz , eklediiniz resim orjinal boyutunda grntlenir.',
    28 => '<p><b>NZLEME</b>: Eer yaznza bir resim eklediyseniz nizleme yapmak yerine Taslak olarak kaydetmeniz gerekir. nzleme seenei yalnzca resim atalanmam iken kullanlabilir.',
    29 => 'Trackbacks',
    30 => 'Dosya Upload Hatalar',
    31 => 'Ltfen, Yazar, Balk ve Konu alanlarn doldurunuz.',
    32 => 'ncelikli',
    33 => 'Sadece bir tane ncelikli yaz olabilir.',
    34 => 'Taslak',
    35 => 'Evet',
    36 => 'Hayr',
    37 => 'Yazdklar:',
    38 => 'Yazlanlar:',
    39 => 'Emailler',
    40 => '',
    41 => "Eriim hakknz olmayan bir yazya erimek istiyorsunuz. Bu eyleminiz kaytlara eklenmitir. Bu yazya salt okunur ekilde aadan eriebilirsiniz. iniz bittii zaman ltfen <a href=\"{$_CONF['site_admin_url']}/story.php\">kontrol ekranna dnnz</a>.",
    42 => "Eriim hakknz olmayan bir yazya erimek istiyorsunuz.  Bu eyleminiz kaytlara eklenmitir.  Ltfen <a href=\"{$_CONF['site_admin_url']}/story.php\">kontrol ekranna geri dnnz</a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>NOT:</b> eer ileride bir tarih verirseniz, yaznz o tarihe kadar yaymlanmayacaktr. Bu ayn zamanda bu yaznn RDF balklarnda ve arama ve istatistik sayfalarda grntlenmeyecektir.',
    47 => 'Resimler',
    48 => 'resim',
    49 => 'sa',
    50 => 'sol',
    51 => 'Bu resimlerden birini yazmakta olduunuz yazya eklemek istiyorsanz, eklemek istediiniz yere: [imageX], [imageX_right] veya [imageX_left] yazn. Burada, X eklediiniz resimin numarasdr. left ve right ekleri imajn sola veya saa dayal olarak kmasna neden olur. NOT: Sadece eklediiniz resimleri kullanabilirsiniz.  Eer eklediiniz resimleri kullanmazsanz yaznz kaydedemezsiniz.<BR><P><B>n zleme</B>:  Resim eklenmi bir yazy n zlem\'de grntlemenin en iyi yolu: nce yaznz Taslak olarak kaydetmenizdir. Bir yazy eer resimleri eklenmediyse n zleme butonunu kullanarak grntleyebilirsiniz.',
    52 => '',
    53 => 'kullanlmad. Bu resmi zet veya yaz blmlerinden birinde kullanmadan deiiklikleri kaydedemezsiniz',
    54 => 'Eklenen Resimler Kullanlmad',
    55 => 'Aadaki hatalar yaznz kaydetmeye alrken olutu.  Ltfen listelenen hatalar kontrol edip dzeltiniz',
    56 => 'Sembol Gster',
    57 => 'leksiz resim gster',
    58 => 'Yaz Ynetimi',
    59 => 'Ayar',
    60 => '',
    61 => 'Auto Archive',
    62 => 'Otomatik Silme',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'erik Dzenleme Alann Genilet',
    68 => 'erik Dzenleme Alann Daralt',
    69 => 'Yaz Yaym Tarihi',
    70 => 'Toolbar Seimi',
    71 => 'Basit Toolbar',
    72 => 'Genel Toolbar',
    73 => 'Gelimi Toolbar',
    74 => 'Gelimi II Toolbar',
    75 => 'Full zellikli',
    76 => 'Yaym zellikleri',
    77 => 'Advanced Editor altrabilmek iin Javascript gereksinimi vardr.  config.php den gerekli ayarlar yapabilirsiniz',
    78 => 'Click <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">here</a> to use default editor',
    79 => 'n zleme',
    80 => 'Editr',
    81 => 'Yaym Ayarlar',
    82 => 'Resimler',
    83 => 'Arivleme Ayarlar',
    84 => 'Eriim Haklar',
    85 => 'Tmn Gster',
    86 => 'Gelimi Editor',
    87 => 'Yaz statistikleri',
    88 => 'Wiki-style format',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'You can always hit "Preview" to extend the expiry time.',
    'autotag_desc_story' => '[story: id alternate title] - Displays a link to a Story using the Story Title as the title. An alternate title may be specified but is not required.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => 'Konu Dzenle',
    2 => 'Konu Tanmlayc',
    3 => 'Konu Ad',
    4 => 'Konu Resmi',
    5 => '(boluk kullanmayn)',
    6 => 'Bir konuyu sildiiniz zaman o konuyla ilikili tm yazlar ve bloklar silinecektir',
    7 => 'Ltfen Konu Tanmlayc ve  Konu Ad alanlarn doldurunuz',
    8 => 'Konu Yneticisi',
    9 => 'Bir konuyu deitirmek veya silmek istiyorsanz, konunun adna basnz.  Yeni bir konu yaratmak istiyorsanz, soldaki Yeni Konu dmesine basnz. Her konuya olan eriim haklarnz parantez iinde grebilirsiniz',
    10 => 'Sralama',
    11 => 'Yaz/Sayfa',
    12 => 'Eriim Engellendi',
    13 => "Eriim hakknz olmayan bir konuya erimek istiyorsunuz.  Bu eyleminiz kaytlara eklenmitir. Ltfen <a href=\"{$_CONF['site_admin_url']}/topic.php\">konu kontrol ekranna geri dnnz</a>.",
    14 => 'Sralama yntemi',
    15 => 'alfabetik',
    16 => 'standart',
    17 => 'Yeni Konu',
    18 => 'Kontrol Ana Sayfas',
    19 => 'kaydet',
    20 => 'vazge',
    21 => 'sil',
    22 => 'Varsaylan',
    23 => 'bildirilen yeni yaz iin bunu varsaylan balk yap',
    24 => '(*)',
    25 => 'Archive Topic',
    26 => 'Arivlenmi yazlar iin geerli balk yap.Sadece bir konu izinli.',
    27 => 'Veya Konu Simgesi Upload Et',
    28 => 'EN Fazla',
    29 => 'Dosya Upload Hatalar',
    30 => 'Stories in Topic'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => 'Kullanc Dzenle',
    2 => 'Kullanc Tanmlaycs',
    3 => 'Kullanc Ad',
    4 => 'Gerek Ad',
    5 => 'ifresi',
    6 => 'Gvenlik Seviyesi',
    7 => 'Email Adresi',
    8 => 'Web Sitesi',
    9 => '(boluk kullanmayn)',
    10 => 'Ltfen Kullanc Ad, Gerek Ad, Gvenlik Seviyesi, ve Email Adresi alanlarn doldurunuz',
    11 => 'Kullanc Dzenleyici',
    12 => 'Bir kullancnn bilgilerini deitirmek veya silmek istiyorsanz, kullanc adna basnz.  Yeni bir kullanc yaratmak istiyorsanz, soldaki Yeni Kullanc dmesine basnz. Aadaki formda kullanc adn, email adresini veya gerek adn girerek basit aramalar yapabilirsiniz (rnein *son* or *.edu).',
    13 => 'Gvenlik Seviyesi',
    14 => 'Kayt Tarihi',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => 'kaydet',
    21 => 'Setiiniz kullanc ad kullanlmakta.',
    22 => 'Hata',
    23 => 'Birden Fazla Kullanc Ekleme',
    24 => 'Birden Fazla Kullanc Ekleme',
    25 => 'Geeklog programna birden fazla kullancy ekleyebilirsiniz. Sekme ile ayrlm bir metin dosyasnn iine alanlar u sra ile ekleyin: gerek ad, kullanc ad, email adresi.  Eklenen her kullancya rasgele atanm bir ifre, kullancnn email adresine gnderilecektir. Her satra sadece bir kullanc adnn eklenmi olmasna dikkat ediniz. Herhangi bir yanllkta eklenen her kullancy tek tek dzeltmek zorunda kalabilirsiniz. Bu yzden dosyanz iki kere kontrol edin!',
    26 => '',
    27 => '',
    28 => 'Resmi silmek iin buray sein',
    29 => 'Adres',
    30 => 'Dardan al',
    31 => 'Yeni Kullanclar',
    32 => 'Ekleme ilemi tamamland. %d kullanc eklendi ve %d hata olutu',
    33 => 'gnder',
    34 => 'Hata: Ykleme yapmak iin bir dosya semi olmanz gerekiyor.',
    35 => 'Son Giri',
    36 => '(asla)',
    37 => 'UID',
    38 => 'Grup Listeleniyor',
    39 => 'ifre (tekrar)',
    40 => 'Kayt Tarihi',
    41 => 'Son Login Tarihi',
    42 => 'Yasakland',
    43 => 'Aktivasyon Bekliyor',
    44 => 'Yetkilendirilme ',
    45 => 'Aktif',
    46 => 'ye Durumu',
    47 => 'Dzenle',
    48 => 'Admin Gruplarn Gster',
    49 => 'Admin Gruplar',
    50 => 'Check to allow filtering this group as an Admin Use Group',
    51 => 'Online Gnler',
    52 => '<br' . XHTML . '>Note: "Online Gnler" lk ye olunan tarih ve son giri tarihi arasnda ki gn saysdr.',
    53 => 'ye Oldu',
    54 => 'Toplu Silme',
    55 => 'Bu ilem yalnzca config.php de <code>$_CONF[\'lastlogin\'] = true;</code> eklinde ayarladnzda alr',
    56 => 'Silmek istediiniz kullanc tipini seip "Listeyi Gncelle" butonuna basnz. Ardndan, silmek istemediiniz kullanclarn iaretini kaldrp "Sil" butonuna basnz. Please note that you will only delete those that are currently visible in case the list spans over several pages.',
    57 => 'Phantom yeler',
    58 => 'Ksa Sreli yeler',
    59 => 'Eski yeler',
    60 => 'u kadar zaman nce ye olanlar ',
    61 => ' ay nce , fakat hi giri yapmayanlar.',
    62 => 'u kadar zaman nce ye olanlar  ',
    63 => ' ay nce ye olan ve 24 saat iinde giri yapan ancak bu tarihten sonra tekrar giri yapmayan yeler.',
    64 => 'Normal yeler, u kadar zamandr siteye uramayanlar ',
    65 => ' ay.',
    66 => 'Listeyi Gncelle',
    67 => 'Aydr ye',
    68 => 'Online Saatler',
    69 => 'Offline Aylar',
    70 => 'Silinemedi',
    71 => 'Baaryla Silindi',
    72 => 'Silinecek ye Seilmedi',
    73 => 'Setiiniz TM Kullanclar silmek istediinize emin misiniz?',
    74 => 'Son yeler',
    75 => 'Son Kaydolan yeler ',
    76 => ' ay',
    77 => 'Email site login reminder to selected users',
    78 => 'Send Reminder',
    79 => 'No User selected for reminders',
    80 => 'Successfully sent Reminders',
    81 => 'Reminder to verify account for %s',
    82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
    83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
    84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
    85 => 'If you have forgotten the password use the following link: %s',
    86 => 'Include',
    87 => 'Reminders',
    88 => 'Default Group',
    89 => 'Check to make this a default group for new users',
    90 => 'Apply "Default Group" change to existing user accounts',
    'autotag_desc_user' => '[user: id alternate title] - Displays a link to a User using the Username as the title. An alternate title may be specified but is not required.'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => 'Onayla',
    2 => 'Sil',
    3 => 'Deitir',
    4 => 'Profil',
    10 => 'Balk',
    11 => 'Balang Tarihi',
    12 => 'URL',
    13 => 'Kategori',
    14 => 'Tarih',
    15 => 'Konu',
    16 => 'Kullanc ad',
    17 => 'Gerek ad',
    18 => 'Email',
    34 => 'Kontrol',
    35 => 'Eklenen Yazlar',
    36 => 'Parent or Comment',
    37 => '',
    38 => 'Gnder',
    39 => 'Onaylamanz gereken herhangi bir eklenti yok',
    40 => 'Kullanclarn ekledikleri',
    41 => 'Comment Submissions',
    42 => 'Username',
    43 => 'Auto-publish Comments?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => "{$_CONF['site_name']} Mesaj Program",
    2 => 'Kimden',
    3 => 'Cevaplama Adresi',
    4 => 'Konu',
    5 => 'erik',
    6 => 'Gnderim:',
    7 => 'Kullanc Ekle',
    8 => 'Admin',
    9 => 'zellikler',
    10 => 'HTML',
    11 => 'Acil Mesaj!',
    12 => 'Gnder',
    13 => 'Temizle',
    14 => 'Kullanc ayarlarn dikkate alma',
    15 => 'Kullanc(lar)a gnderilemiyor: ',
    16 => 'Kullanc(lar)a baaryla gnderildi: ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>Bir mesaj daha gnder</a>",
    18 => 'Kime',
    19 => 'NOT: eer btn site yelerine mesaj gndermek istiyorsanz, seim listesinden Sitedeki Kullanclar grubunu seiniz.',
    20 => "<successcount> mesaj baaryla gnderildi ama <failcount> mesajn gnderilmesinde sorun kt. Her gnderme denemesinin ayrntlar aada bulunmaktadr. <a href=\"{$_CONF['site_admin_url']}/mail.php\">Baka bir mesaj gnderebilir</a>, veya <a href=\"{$_CONF['site_admin_url']}/moderation.php\">Kontrol Ana Sayfas</a>na geri dnebilirisiniz.",
    21 => 'Baarsz',
    22 => 'Baarl',
    23 => 'Baarsz olan gnderim yok',
    24 => 'Baarl olan gnderim yok',
    25 => '-- Grup sein --',
    26 => 'Ltfen formun tm alanlarn doldurun ve eim listesinden bir kullanc grubu sein.'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => 'Sisteme eklenti (plug-in) ykleyerek Geeklog\'un almasn ve belki sisteminizi bozabilirsiniz. Sadece <a href="http://www.geeklog.net" target="_blank">Geeklog Ana Sayfas</a>\'ndan yklediiniz eklentileri yklemeniz tavsiye edilir, nk bize ulaan tm eklentileri eitli iletim sistemleriyle ayrntl testlere sokuyoruz. zellikle nc firmalardan yklediiniz eklentilerin yklenirken sisteminize zarar verebilecek programlar altrabileceini ve bunlarn gvenlik aklarna neden olabileceini anlamanz nemlidir. Bu uyarya ramen, biz bu eklentinin yklenmesinin baaryla tamamlanacan garanti etmiyoruz, ve sisteminizde doacak herhangi bir hasardan dolay sorumluluk kabul etmiyoruz. Baka bir deyile eklentiyi yklerken doacak tm riskler size aittir.  Ayrntlar renmek isteyenler iin her eklenti paketinde yklemenin el ile yaplabilmesi iin ayrntlar ve admlar mevcuttur.',
    2 => 'Eklenti Ykleme ile lgili Ykmler',
    3 => 'Eklenti Ykleme Formu',
    4 => 'Eklenti Dosyas',
    5 => 'Eklenti Listesi',
    6 => 'Uyar: Eklenti zaten yklenmi!',
    7 => 'Yklemeye altnz eklenti zaten yklenmi. Eer yeniden yklemek istiyorsanz, eklentiyi nce silin.',
    8 => 'Eklenti uyumluluk kontrol baarsz.',
    9 => 'Bu eklenti Geeklog\'un yeni bir versiyonun istemekte. Elinizdeki kopyay ya <a href="http://www.geeklog.net">Geeklog</a> adresinden yenileyin ya da eklentinin yeni bir versiyonunu bulmalsnz.',
    10 => '<br' . XHTML . '><b>u anda hi bir eklenti yklenmemi.</b><br' . XHTML . '><br' . XHTML . '>',
    11 => 'Bir eklentiyi deitirmek veya silmek istiyorsanz eklentinin numarasna basn. Eklenti hakknda daha fazla bilgi edinmek iin eklentinin adna basn. Bu eklentinin web sitesini aar. Bir eklenti yklemek veya srmn yenilemek iin dokmantasyonuna bavurun.',
    12 => 'plugineditor()\'e hi bir eklenti ad salanmad',
    13 => 'Eklenti Dzenle',
    14 => 'Yeni Eklenti',
    15 => 'Kontrol Ana Sayfas',
    16 => 'Eklenti Ad',
    17 => 'Eklenti Srm',
    18 => 'Geeklog Srm',
    19 => 'Kullanmda',
    20 => 'Evet',
    21 => 'Hayr',
    22 => 'Ykle',
    23 => 'Kaydet',
    24 => 'Vazge',
    25 => 'Sil',
    26 => 'Eklenti ad',
    27 => 'Eklenti Web Sitesi',
    28 => 'Eklenti Srm',
    29 => 'Geeklog Srm',
    30 => 'Eklentiyi Sil?',
    31 => 'Bu eklentiyi silmek istediinizden eminmisiniz? Bunu yaparsanz eklentinin kulland tm veriler ve veri yaplar da silinecektir. Eminseniz Sil dmesine bir daha basnz.',
    32 => '<p><b>Hata: AutoLink tag doru formatta deil</b></p>',
    33 => 'Yazlm versionu',
    34 => 'Gncelle',
    35 => 'Dzenle',
    36 => 'Code',
    37 => 'Data',
    38 => 'Gncelle!',
    39 => 'Upload a plugin',
    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
    41 => 'Upload',
    42 => 'Click to update',
    43 => 'Load Order',
    44 => 'Move plugin up the load order',
    45 => 'Move plugin down the load order',
    46 => 'Click to Delete this Plugin',
    47 => 'Really Delete %s Plugin?',
    48 => 'Click to Enable this Plugin',
    49 => 'Click to Disable this Plugin',
    50 => 'Dependencies',
    51 => 'OK',
    52 => 'Unresolved',
    53 => 'Disabled',
    54 => 'Unavailable',
    55 => 'Uninstalled',
    56 => 'Wrong Version',
    57 => 'Unknown',
    58 => 'The load order of one or more plugins has been altered in order to resolve dependencies',
    59 => 'Info',
    60 => 'Close',
    61 => 'Status',
    62 => 'Click to Install this Plugin',
    63 => 'This Plugin Cannot be Installed',
    64 => 'This Plugin Cannot be Enabled',
    65 => 'The plugin upload function has been disabled due to the following errors:',
    66 => 'File uploads are disabled in your PHP configuration.',
    67 => 'The directory "%s" is not writable.',
    68 => 'You do not have the required permissions to install plugins.',
    69 => 'You do not have the required permissions to upload plugins.',
    99 => 'An unknown error occured',
    100 => 'Ok.',
    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
    103 => 'The uploaded file was only partially uploaded.',
    104 => 'No file was uploaded.',
    105 => '(undefined error)',
    106 => 'Missing a temporary folder.',
    107 => 'Failed to write file to disk.',
    108 => 'File upload stopped by extension.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => 'Olutur feed',
    2 => 'Kaydet',
    3 => 'Sil',
    4 => 'Vazge',
    10 => 'Content Syndication',
    11 => 'Yeni Feed',
    12 => 'Admin Home',
    13 => 'Bir feedi silmek veya dzenlemek iin , aadaki feed\'in  balna tklayn. Yeni bir feed oluturmak iin , yukarda ki Yeni Feed e tklayn.',
    14 => 'Balk',
    15 => 'Tip',
    16 => 'Dosya Ad',
    17 => 'Format',
    18 => 'Son Gncelleme',
    19 => 'zinli',
    20 => 'Evet',
    21 => 'Hyr',
    22 => '<i>(feed yok)</i>',
    23 => 'Tm Yazlar',
    24 => 'Feed Dzenleyici',
    25 => 'Feed Bal',
    26 => 'Limit',
    27 => 'Giri uzunluu',
    28 => '(0 = no text, 1 = full text, other = limit to that number of chars.)',
    29 => 'Aklama',
    30 => 'Son Gncelleme',
    31 => 'Karakter Set',
    32 => 'Dil',
    33 => 'erik',
    34 => 'Entries',
    35 => 'Saat',
    36 => 'feedin Tipini sein',
    37 => '',
    38 => 'Hata: Bo Braklan Alanlar',
    39 => 'Ltfen Feed Bal, Aklama ve Dosya Ad alanlarn doldurunuz.',
    40 => 'Ltfen bir say girin of entries or number of Saat.',
    41 => 'Linkler',
    42 => '',
    43 => 'Hepsi',
    44 => 'Hibirisi',
    45 => 'Header-link in topic',
    46 => 'Sonu Limiti',
    47 => 'Arama',
    48 => 'Dzenle',
    49 => 'Feed Logo',
    50 => "Relative to site url ({$_CONF['site_url']})",
    51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
    52 => 'HATA: Bu Dosya Ad var',
    53 => 'All Frontpage Stories',
    54 => 'Please select the type of feed to create.',
    55 => 'Articles'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "ifreniz email adresinize gnderilmitir. Ltfen, email adresinize gelen mesajdaki admlar uygulayn. (Eer ifreniz elinize ulamadysa ltfen Junk-Bulk Mail Klasrnz kontrol edin) {$_CONF['site_name']} kullandnz iin teekkr ederiz.",
    2 => 'Yaznz sitemize gnderdiiniz iin teekkr ederiz.  Yaznz, site ynetimi tarafndan onaylandktan sonra yaymlanacaktr.',
    3 => '',
    4 => '',
    5 => 'Kayt bilgileriniz baarl bir ekilde kaydedildi.',
    6 => 'Grnm ayarlarnz baarl bir ekilde kaydedildi.',
    7 => 'Yorum tercihleriniz baarl bir ekilde kaydedildi.',
    8 => 'Sistemden baaryla ktnz.',
    9 => 'Yaznz baaryla kaydedildi.',
    10 => 'Yaznz baaryla silindi.',
    11 => 'Blounuz baaryla kaydedildi.',
    12 => 'Blounuz baaryla silindi.',
    13 => 'Konunuz baaryla kaydedildi.',
    14 => 'Konunuz ve btn yazlar ve alanlar baaryla silindi.',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => 'Yeni kullanc baaryla kaydedildi.',
    22 => 'Yeni kullanc baaryla silindi.',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => 'Mesaj baarlya iletildi.',
    28 => 'Eklenti baaryla eklendi.',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => 'Eriim Engellendi',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => 'Sistem Mesaj',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Eklenti baarlya yklendi!',
    45 => 'Eklenti baaryla silindi.',
    46 => '',
    47 => '',
    48 => "{$_CONF['site_name']} sitesine yelik bavurunuz iin teekkr ederiz. Site ynetimi bavurunuzu inceleyecektir. Eer kabul alrsanz ifreniz belirttiiniz email adreisne gnderilecektir.",
    49 => 'Grubunuz baaryla kaydedildi.',
    50 => 'Grup baaryla silindi.',
    51 => 'Bu kullanc ad zaten kullanlyor. Ltfen baka bir tane sein.',
    52 => 'Salanan email adresi geerli bir email adresi olarak gzkmyor.',
    53 => 'Yeni ifreniz kabul edildi. Ltfen aadan yeni ifrenizi kullanarak imdi giri yapn.',
    54 => 'Yeni bir ifre isteme sreniz doldu. Ltfen aadan tekrar deneyin.',
    55 => 'Size bir email gnderildi ve az nce yerine ulat. Hesabnza yeni bir ifre tayin etmek iin mesajdaki talimatlar ltfen takip ediniz.',
    56 => 'Salanan email adresi zaten baka bir hesap tarafndan kullanlyor.',
    57 => 'Hesabnz baaryla silindi.',
    58 => 'Your feed baaryla kaydedildi.',
    59 => 'The feed baaryla silindi.',
    60 => 'Eklenti baaryla gncellendi',
    61 => 'Plugin %s: Unknown message placeholder',
    62 => 'Trackback iletisi silindi.',
    63 => 'Trackback iletisi silinirken hata olutu.',
    64 => 'Trackback iletiniz baaryla gnderildi.',
    65 => 'Weblog dizin servisi baaryla saved.',
    66 => 'Weblog dizin servisi  silindi.',
    67 => 'Yeni ifreniz does not match the confirmation password!',
    68 => 'You have to enter the correct current password.',
    69 => 'yeliiniz Bloke edildi!',
    70 => 'yeliiniz ynetici onay bekliyor.',
    71 => 'yeliiniz teyid edildi ve ynetici onay bekliyor.',
    72 => 'Eklenti kurulumunda hata olutu. Ayrntlar iin  error.log dosyasna baknz.',
    73 => 'Eklenti kaldrlrken bir hata olutu. Ayrntlar iin  error.log dosyasna baknz',
    74 => 'pingback baaryla gnderildi.',
    75 => 'Trackbacklar POST sorgulamas gerektirmektedir.',
    76 => 'Bu eyi gerekten silmek istiyor musunuz?',
    77 => 'DKKAT:<br' . XHTML . '>Geerli dil kodlamanz UTF-8 dir. Ancak, servernz bu kodlamay desteklememektedir. Ltefen PHP iin mbstring fonsiyonunu kurunuz veya farkl bir dil kodlamas/dil seiniz.',
    78 => 'Girdiiniz iki mail adresininde ayn olduuna emin olun.',
    79 => 'The page you have been trying to open refers to a function that no longer exists on this site.',
    80 => 'The plugin that created this feed is currently disabled. You will not be able to edit this feed until you re-enable the parent plugin.',
    81 => 'You may have mistyped your login credentials.  Ltfen yeniden giri yapmay deneyin.',
    82 => 'zin verilen giri saysn atnz.  Ltfen daha sonra tekrar deneyin.',
    83 => 'ifrenizi, e-mail adresini deitirmek veya ne sistemin ifrenizi kadar hatrlayacan belirlemek iin ltfen ifrenizi girin.',
    84 => 'Hesabnza silmek iin ifrenizi giriniz.',
    85 => 'There was a problem sending the email.',
    86 => 'The OpenID server invalidated your login attempt.',
    87 => 'OpenID login operation cancelled by user.',
    88 => 'The OpenID server returned an error.',
    89 => 'Unable to find an OpenID server for the given identity URL.',
    90 => 'OpenID identification cancelled.',
    91 => 'You specified an invalid identity URL.',
    92 => "Please <a href=\"{$_CONF['site_admin_url']}/sectest.php\">check the security of your site</a> before using it!",
    93 => 'Database back up was successful.',
    94 => 'Backup Failed: Filesize less than 1kb',
    95 => 'There was an error.',
    96 => '',
    97 => '',
    98 => 'The plugin was successfully uploaded.',
    99 => 'The plugin already exists.',
    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
    110 => 'Can not get URL for authentication.',
    111 => 'Authentication error.',
    112 => 'Certification has been canceled.',
    113 => 'Your account has been created successfully. {site_url}',
    114 => 'Your re-synch with your remote account has failed but your other account information has been successfully saved.',
    115 => 'Remote service has been disabled.',
    400 => 'Not all required fields have been passed validation',
    401 => 'Please enter Fullname'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => 'Eriim',
    'ownerroot' => 'Sahibi/Root',
    'group' => 'Grup',
    'readonly' => 'Salt Okunur',
    'accessrights' => 'Eriim Haklar',
    'owner' => 'Sahibi',
    'grantgrouplabel' => 'Yukardaki Grup Deitirme Haklarna zin Ver',
    'permmsg' => 'NOT: yeler bu sitenin, siteye girmi olan yelerine denir, ve Herhangi ise sitede bulundan ama siteye giri yapmam herhangi bir kullancya denir.',
    'securitygroups' => 'Gvenlik Gruplar',
    'editrootmsg' => "Kullanc Yneticisi olmanza ramen root kullancsn, root kullancs olmadan deitiremezsiniz. Root kullancs dnda herhangi bir kullancy deitirebiliriniz. Root kullancsna olan izinsiz tm etkinlikler kaydedilmektedir. Ltfen <a href=\"{$_CONF['site_admin_url']}/user.php\">Kullarnc Kontrol Sayfas</a>'na geri dnn.",
    'securitygroupsmsg' => 'Kullancnn bulunmasn istediiniz gruplar ltfen seiniz.',
    'groupeditor' => 'Grup Dzenleyicisi',
    'description' => 'Tanm',
    'name' => 'Ad',
    'rights' => 'Haklar',
    'missingfields' => 'Eksik Bloklar',
    'missingfieldsmsg' => 'Gruba bir Ad ve Tanm vermelisiniz.',
    'groupmanager' => 'Grup Dzenleyicisi',
    'newgroupmsg' => 'Bir grubu deitirmek veya silmek istiyorsanz, grubun adna basnz. Yeni bir grup yaratmak iin yukardan Yeni Grup dmesine basnz. Sistem tarafndan yaratlm temel gruplar sistem tarafndan kullanld iin silinemez.',
    'groupname' => 'Grup Ad',
    'coregroup' => 'Temel Grubu',
    'yes' => 'Evet',
    'no' => 'Hayr',
    'corerightsdescr' => "Bu grup bir temel {$_CONF['site_name']} grubudur.  Bu nedenden bu grubun eriim haklar deitirlemez. Aada bu grubun hangi haklara sahip olduunun listesi bulunmaktadr.",
    'groupmsg' => 'Bu sitede kullanlan gvenlik gruplar hiyerariktir. Bir grubu bu gruba ekleyerek bu grubun sahip olduu eriim haklaryla ayn eriim haklarn eklediiniz gruba vermi olursunuz. Bir gruba gvenlik haklar vermek iin aadaki gruplar kullanarak gruplar oluturman nerilir. Eer bir gruba zel haklar vermek istiyorsanz, aadaki \'Haklar\' blmnden istediiniz zellikleri seebilirsiniz. Bu grubu bir baka grup(lar)n altna eklemek iin sadece aadaki gruplardan istediklerinizi sein.',
    'coregroupmsg' => "Bu grup bir temel {$_CONF['site_name']} grubudur.  Bu yzden bu grubun bulunduu gruplar deitirilemez. Bu grubun bulunduu gruplarn salt okunur listesi aadadr.",
    'rightsdescr' => 'Bir grubun bir eriim hakk buradan verilebilir veya grubun bir st grubu varsa o gruba verilerek bu gurubun almas salanabilinir. Aada eer seme kutusu olmayan haklar varsa bunlar bu grubun yesi olduu bir st gruba verilmi olan haklardr. Seme kutusu olan haklar seerek bu gruba daha geni bir hak verebilirsiniz.',
    'lock' => 'Kilit',
    'members' => 'yeler',
    'anonymous' => 'simsiz Kullanc',
    'permissions' => 'zinler',
    'permissionskey' => 'R = oku, E = dzenle, haklarda deiiklik yap',
    'edit' => 'Deitir',
    'none' => 'Hibiri',
    'accessdenied' => 'Eriim Engellendi',
    'storydenialmsg' => "Bu yazy okuma yetkiniz yok. Bunun nedeni {$_CONF['site_name']} sitesinin bir yesi olmamanzdan kaynaklanyor olabilir. Ltfen {$_CONF['site_name']} sitesinin <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> yesi olun</a> ve sadece yelere verilen haklara kavuun!",
    'nogroupsforcoregroup' => 'Bu grup bir baka gruba dail deil.',
    'grouphasnorights' => 'Bu grup, sitenin hi bir ynetimsel zelliklerine sahip deil.',
    'newgroup' => 'Yeni Grup',
    'adminhome' => 'Kontrol Ana Sayfas',
    'save' => 'kaydet',
    'cancel' => 'vazge',
    'delete' => 'sil',
    'canteditroot' => 'Root grubu deitirmeye altnz, fakat root grubun bir yesi deilsiniz. Bu nedenden eriiminiz engellendi. Eer bunun bir hata olduunu dnyorsanz sistem yneticinize dann.',
    'listusers' => 'ye Listesi',
    'listthem' => 'liste',
    'usersingroup' => 'ye grubu %s',
    'usergroupadmin' => 'User Group Ynetimi',
    'add' => 'Ekle',
    'remove' => 'Kaldr',
    'availmembers' => 'Available Kullanclar',
    'groupmembers' => 'Grup yeleri',
    'canteditgroup' => 'Bu gurubu dzenleyebilmek iin, bu grubum bir yesi olmalsnz. Please contact the system administrator if you feel this is an error.',
    'cantlistgroup' => 'To see the members of this group, you have to be a member yourself. Please contact the system administrator if you feel this is an error.',
    'editgroupmsg' => 'To modify the group membership, click on the member names(s) and use the add or remove buttons. If the member is a member of the group, their name will appear on the right side only. Once you are complete - press <b>Save</b> to update the group and return to the main group admin page.',
    'listgroupmsg' => 'Listing of all current members in the group: <b>%s</b>',
    'search' => 'Ara',
    'submit' => 'Submit',
    'limitresults' => 'Limit Results',
    'group_id' => 'Grup ID',
    'plugin_access_denied_msg' => 'Ynetim sayfasna yetkisiz olarak girmeye altnz.  Ip numaranz ve Adnz Kaydedildi.',
    'groupexists' => 'Grup ad Kullanlyor',
    'groupexistsmsg' => 'Setiiniz grup ad kullanlmda, baka bir grup ad seiniz.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => 'Son 10 yedekleme',
    'do_backup' => 'Yedekleme Yap',
    'backup_successful' => 'Veritaban yedeklemesi baaryla sonuland.',
    'db_explanation' => 'Geeklog sisteminin yeni bir yedeini almak iin, aadaki butona basn.',
    'not_found' => "Hatal adres veya mysqldump program altrlnamyor.<br" . XHTML . ">config.php dosyanzdaki <strong>\$_DB_mysqldump_path</strong> deikenini kontrol edin.<br" . XHTML . ">Deiken u anki deeri: <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => 'Yedekleme baarsz: Dosya boyutu 0 bayt idi.',
    'path_not_found' => "{$_CONF['backup_path']} adresi yok veya bir klasr deil",
    'no_access' => "HATA: Kalsr {$_CONF['backup_path']} eriilinemiyor.",
    'backup_file' => 'Yedek dosyas',
    'size' => 'Boyut',
    'bytes' => 'Bayt',
    'total_number' => 'Toplam backup says: %d',
    'download' => 'Click to download this file',
    'new_backup' => 'New Backup',
    'delete_failure' => 'One or more backup files could not be deleted.',
    'delete_success' => 'Backup file(s) successfully deleted.',
    'convert_menu' => 'Convert to InnoDB',
    'convert_title' => 'Convert to InnoDB tables',
    'convert_button' => 'Convert',
    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
    'innodb_success' => 'Successfully converted tables to InnoDB.',
    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
    'optimize_menu' => 'Optimize Tables',
    'optimize_title' => 'Optimize Tables',
    'optimize_button' => 'Optimize',
    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
    'last_optimization' => 'Last optimization',
    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
    'optimize_success' => 'Successfully optimized database tables.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => 'Ana Sayfa',
    2 => 'letiim',
    3 => 'Yaz Yazn',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Site statistikleri',
    8 => 'zelletir',
    9 => 'Ara',
    10 => 'Gelimi Arama',
    11 => 'Dizin'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => '404 Hatas',
    2 => 'ff, her yere baktm ama <b>%s</b> bulamadm.',
    3 => "<p>zgnz, belirttiiniz dosya bulunamyor. Ltfen <a href=\"{$_CONF['site_url']}\">ana sayfa</a>ya veya <a href=\"{$_CONF['site_url']}/search.php\">arama sayfas</a>'na bakarak kaybettiiniz dokman bulabilecekmisiniz bir bakn."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => 'Sisteme giri yapmanz gerekiyor',
    2 => 'zgnm, bu alana giri yapabilmeniz iin bir kullanc olarak giri yapmanz gerekiyor.',
    3 => 'Giri yap',
    4 => 'Yeni Kullanc'
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'Kimden',
    'tracked_on' => 'Tracked on',
    'read_more' => '[devamn oku]',
    'intro_text' => 'Here\'s what others have to say about \'%s\':',
    'no_comments' => 'Trackback iletisi yok.',
    'this_trackback_url' => 'Bu yaz iin Trackback URL si:',
    'num_comments' => '%d trackback iletileri',
    'send_trackback' => 'Ping Gnder',
    'preview' => 'n zleme',
    'editor_title' => 'trackback comment',
    'trackback_url' => 'Trackback URL',
    'entry_url' => 'Entry URL',
    'entry_title' => 'Entry Title',
    'blog_name' => 'Site Name',
    'excerpt' => 'Excerpt',
    'truncate_warning' => 'Note: The receiving site may truncate your excerpt',
    'button_send' => 'Gnder',
    'button_preview' => 'z zleme',
    'send_error' => 'Error',
    'send_error_details' => 'Error when sending trackback comment:',
    'url_missing' => 'No Entry URL',
    'url_required' => 'Please enter at least a URL for the entry.',
    'target_missing' => 'Trackback URL si YOK',
    'target_required' => 'Ltfen bir trackback URL si giriniz',
    'error_socket' => 'Could not open socket.',
    'error_response' => 'Response not understood.',
    'error_unspecified' => 'Unspecified error.',
    'select_url' => 'Trackback URLsi Seiniz',
    'not_found' => 'Trackback URL not found',
    'autodetect_failed' => 'Geeklog could not detect the Trackback URL for the post you want to Gnder your comment to. Please enter it manually below.',
    'trackback_explain' => 'From the links below, please select the URL you want to Gnder your Trackback comment to. Geeklog will then try to determine the correct Trackback URL for that post. Or you can <a href="%s">enter it manually</a> if you know it already.',
    'no_links_trackback' => 'No links found. You can not Gnder a Trackback comment for this entry.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Pingback results',
    'send_pings' => 'Gnder Pings',
    'send_pings_for' => 'Gnder Pings for "%s"',
    'no_links_pingback' => 'No links found. No Pingbacks were sent for this entry.',
    'pingback_success' => 'Pingback sent.',
    'no_pingback_url' => 'No pingback URL found.',
    'resend' => 'ReGnder',
    'ping_all_explain' => 'You can now notify the sites you linked to (<a href="http://en.wikipedia.org/wiki/Pingback">Pingback</a>), advertise that your site has been updated by pinging weblog directory services, or Gnder a <a href="http://en.wikipedia.org/wiki/Trackback">Trackback</a> comment in case you wrote about a post on someone else\'s site.',
    'pingback_button' => 'Gnder Pingback',
    'pingback_short' => 'Gnder Pingbacks to all sites linked from this entry.',
    'pingback_disabled' => '(Pingback disabled)',
    'ping_button' => 'Gnder Ping',
    'ping_short' => 'Ping weblog directory services.',
    'ping_disabled' => '(Ping disabled)',
    'trackback_button' => 'Gnder Trackback',
    'trackback_short' => 'Gnder a Trackback comment.',
    'trackback_disabled' => '(Trackback disabled)',
    'may_take_a_while' => 'Please note that Gndering Pingbacks and Pings may take a while.',
    'ping_results' => 'Ping results',
    'unknown_method' => 'Unknown ping method',
    'ping_success' => 'Ping sent.',
    'error_site_name' => 'Please enter the site\'s name.',
    'error_site_url' => 'Please enter the site\'s URL.',
    'error_ping_url' => 'Please enter a valid Ping URL.',
    'no_services' => 'No weblog directory services configured.',
    'services_headline' => 'Weblog Directory Services',
    'service_explain' => 'To modify or delete a weblog directory service, click on the edit icon of that service below. To add a new weblog directory service, click on "Create New" above.',
    'service' => 'Service',
    'ping_method' => 'Ping method',
    'service_website' => 'Website',
    'service_ping_url' => 'URL to ping',
    'ping_standard' => 'Standard Ping',
    'ping_extended' => 'Extended Ping',
    'ping_unknown' => '(unknown method)',
    'edit_service' => 'Edit Weblog Directory Service',
    'trackbacks' => 'Trackbacks',
    'editor_intro' => 'Prepare your trackback comment for <a href="%s">%s</a>.',
    'editor_intro_none' => 'Prepare your trackback comment.',
    'trackback_note' => 'To Gnder a trackback comment for a story, go to the list of stories and click on "Gnder Ping" for the story. To Gnder a trackback that is not related to a story, <a href="%s">click here</a>.',
    'pingback_explain' => 'Enter a URL to Gnder the Pingback to. The pingback will point to your site\'s homepage.',
    'pingback_url' => 'Pingback URL',
    'site_url' => 'This site\'s URL',
    'pingback_note' => 'To Gnder a pingback for a story, go to the list of stories and click on "Gnder Ping" for the story. To Gnder a pingback that is not related to a story, <a href="%s">click here</a>.',
    'pbtarget_missing' => 'No Pingback URL',
    'pbtarget_required' => 'Please enter a pingback URL',
    'pb_error_details' => 'Error when Gndering the pingback:',
    'delete_trackback' => 'To delete this Trackback click: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Article Dizini',
    'title_year' => ' %d iin Article Dizini',
    'title_month_year' => ' %s %d iin Article Dizini',
    'nav_top' => 'Article Dizinine Geri Dn',
    'no_articles' => 'Articles Yok.'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklog Security Check',
    'results' => 'Results of the Security Check',
    'okay' => 'Everything seems to be in order.',
    'please_fix' => 'Please fix the above issues before using your site!',
    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
    'installation' => 'installation instructions',
    'directory' => 'directory',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'This is a security risk and should be fixed!',
    'reachable' => 'Your %s is reachable from the web.',
    'not_reachable' => 'Good! Your %s is not reachable from the web.',
    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
    'inst_removed' => 'Good! You seem to have removed the install directory already.',
    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
    'password_okay' => 'Good! You seem to have changed the default account password already.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n yeni %i in the last %t %s',
    'new_last' => 'son %t %s',
    'minutes' => 'dakikalar',
    'hours' => 'saatler',
    'days' => 'gnler',
    'weeks' => 'haftalar',
    'months' => 'aylar',
    'years' => 'years',
    'minute' => 'dakika',
    'hour' => 'saat',
    'day' => 'gn',
    'week' => 'hafta',
    'month' => 'ay',
    'year' => 'year'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'Ocak',
    2 => 'ubat',
    3 => 'Mart',
    4 => 'Nisan',
    5 => 'Mays',
    6 => 'Haziran',
    7 => 'Temmuz',
    8 => 'Austos',
    9 => 'Eyll',
    10 => 'Ekim',
    11 => 'Kasm',
    12 => 'Aralk'
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => 'Pazar',
    2 => 'Pazartesi',
    3 => 'Sal',
    4 => 'aramba',
    5 => 'Perembe',
    6 => 'Cuma',
    7 => 'Cumartesi'
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Arama',
    'limit_results' => 'Sonu Limiti',
    'submit' => 'Gnder',
    'edit' => 'Dzenle',
    'edit_adv' => 'Glm.Dzenleme',
    'admin_home' => 'Ynetim AnaSayfa',
    'create_new' => 'Yeni Olutur',
    'create_new_adv' => 'Yeni Olutur(Glm.)',
    'enabled' => 'zinli',
    'disabled' => 'Disabled',
    'title' => 'Balk',
    'page_title' => 'Page Title',
    'type' => 'Tip',
    'topic' => 'Konu',
    'info' => 'Info',
    'help_url' => 'Yardm Dosyas URL',
    'save' => 'Kaydet',
    'cancel' => 'Vazge',
    'install' => 'Install',
    'delete' => 'Sil',
    'deleteitem' => 'Delete',
    'delete_sel' => 'Seileni Sil',
    'copy' => 'Kopyala',
    'no_results' => '- Giri Bulunumad -',
    'data_error' => 'Veriniz ilenirken bir hata olutu. Ltfen veri kaynan kontrol edin.',
    'preview' => 'nzleme',
    'records_found' => 'Kayt Bulundu',
    'addchild' => 'Add child',
    'list' => 'list',
    'list_all' => 'List all',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'unavailable' => 'N/A',
    'warning' => '!!!',
    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
    'authenticate' => 'Authenticate'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'Yorum Ekleme zinsiz',
    -1 => 'Yorum Ekleme zinli',
    1 => 'Comments Closed'
);

$LANG_commentmodes = array(
    'flat' => 'Alt Alta',
    'nested' => ' e',
    'threaded' => 'Threaded',
    'nocomment' => 'Yorum Gsterme'
);

$LANG_cookiecodes = array(
    0 => '(don\'t)',
    3600 => '1 Saat',
    7200 => '2 Saat',
    10800 => '3 Saat',
    28800 => '8 Saat',
    86400 => '1 Gn',
    604800 => '1 Hafta',
    2678400 => '1 Ay'
);

$LANG_dateformats = array(
    0 => 'Sistem Default'
);

$LANG_featurecodes = array(
    0 => 'nceliksiz',
    1 => 'ncelikli'
);

$LANG_frontpagecodes = array(
    0 => 'Sadece Konularda Gster',
    1 => 'Anasayfada Gster'
);

$LANG_postmodes = array(
    'plaintext' => 'Text Formatl',
    'html' => 'HTML Formatl'
);

$LANG_sortcodes = array(
    'ASC' => 'nce Eskiler',
    'DESC' => 'nce Yeniler'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback zinli',
    -1 => 'Trackback zinsiz'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Site Administration',
    'sections' => 'Configuration Sections',
    'restore' => 'Restore',
    'add_element' => 'Add Element',
    'save_changes' => 'Save Changes',
    'reset_form' => 'Reset Form',
    'changes_made' => 'Changes were successfully made to',
    'title' => 'Configuration Manager',
    'disable' => 'Click to disable this option',
    'enable' => 'Enable',
    'default_tab_name' => 'Main',
    'search_configuration_label' => 'Search Configuration',
    'error_validation_occurs' => 'There are invalid configuration values. Please correct these fields (just click the config variable to point you to the error field)'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Geeklog Configuration'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'HTML Path',
    'site_url' => 'Site URL',
    'site_admin_url' => 'Admin URL',
    'site_mail' => 'Site E-Mail',
    'noreply_mail' => 'No-Reply E-Mail',
    'site_name' => 'Site Name',
    'site_slogan' => 'Slogan',
    'owner_name' => 'Owner Name',
    'microsummary_short' => 'Microsummary',
    'path_log' => 'Log',
    'path_language' => 'Language',
    'backup_path' => 'Backup',
    'path_data' => 'Data',
    'path_images' => 'Images',
    'path_pear' => 'Path Pear',
    'have_pear' => 'Have Pear?',
    'mail_settings' => 'Mail Settings',
    'allow_mysqldump' => 'Allow MySQL Dump',
    'mysqldump_path' => 'Path of Executable',
    'mysqldump_options' => 'MySQL Dump Options',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Theme',
    'doctype' => 'DOCTYPE Declaration',
    'menu_elements' => 'Menu Elements',
    'path_themes' => 'Themes Path',
    'disable_new_user_registration' => 'Disable New Registrations',
    'allow_user_themes' => 'Allow User Themes',
    'allow_user_language' => 'Allow User Language',
    'allow_user_photo' => 'Allow User Photo',
    'allow_username_change' => 'Allow Username Changes',
    'allow_account_delete' => 'Allow Account Deletion',
    'hide_author_exclusion' => 'Allow Hide Author',
    'show_fullname' => 'Show Fullname',
    'show_servicename' => 'Show Service Name',
    'custom_registration' => 'Enable Custom Registration',
    'user_login_method' => 'User Login Method',
    'facebook_login' => 'Enable OAuth Login Method Facebook',
    'facebook_consumer_key' => 'Facebook OAuth Application ID',
    'facebook_consumer_secret' => 'Facebook OAuth Application Secret',
    'linkedin_login' => 'Enable OAuth Login Method LinkedIn',
    'linkedin_consumer_key' => 'LinkedIn OAuth API Key',
    'linkedin_consumer_secret' => 'LinkedIn OAuth Secret Key',
    'twitter_login' => 'Enable OAuth Login Method Twitter',
    'twitter_consumer_key' => 'Twitter OAuth Consumer Key',
    'twitter_consumer_secret' => 'Twitter OAuth Consumer Secret',
    'spamx' => 'Spam-X Actions',
    'sort_admin' => 'Sort Links',
    'language' => 'Language',
    'locale' => 'Locale',
    'date' => 'Date Format',
    'daytime' => 'Daytime Format',
    'shortdate' => 'Short Date Format',
    'dateonly' => 'Date Only Format',
    'timeonly' => 'Time Only Format',
    'week_start' => 'Week Start',
    'hour_mode' => 'Hour Mode',
    'thousand_separator' => 'Thousands Separator',
    'decimal_separator' => 'Decimal Separator',
    'decimal_count' => 'Decimal Count',
    'language_files' => 'Language Files',
    'languages' => 'Languages',
    'timezone' => 'Timezone',
    'site_disabled_msg' => 'Site Disabled Message or URL',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Session Cookie Name',
    'cookie_name' => 'Permanent Cookie Name',
    'cookie_password' => 'Password Cookie Name',
    'cookie_theme' => 'Theme Cookie Name',
    'cookie_language' => 'Language Cookie Name',
    'cookie_tzid' => 'Timezone Cookie Name',
    'cookie_anon_name' => 'Anon. Username Cookie Name',
    'cookie_ip' => 'Cookies embed IP?',
    'default_perm_cookie_timeout' => 'Permanent Timeout',
    'session_cookie_timeout' => 'Session Timeout',
    'cookie_path' => 'Cookie Path',
    'cookiedomain' => 'Cookie Domain',
    'cookiesecure' => 'Cookie Secure',
    'lastlogin' => 'Record Last Login?',
    'num_search_results' => 'Number of Search Results',
    'loginrequired' => 'Login Required?',
    'submitloginrequired' => 'Submit Login Required?',
    'commentsloginrequired' => 'Comment Login Required?',
    'statsloginrequired' => 'Stats Login Required?',
    'searchloginrequired' => 'Search Login Required?',
    'profileloginrequired' => 'Profile Login Required?',
    'emailuserloginrequired' => 'E-Mail User Login Required?',
    'emailstoryloginrequired' => 'E-Mail Story Login Required?',
    'directoryloginrequired' => 'Directory Login Required?',
    'storysubmission' => 'Story Submission Queue?',
    'usersubmission' => 'User Submission Queue?',
    'listdraftstories' => 'List Draft Stories?',
    'notification' => 'Notifications',
    'postmode' => 'Default Post Mode',
    'speedlimit' => 'Post Speed Limit',
    'skip_preview' => 'Skip Preview in Posts',
    'advanced_editor' => 'Advanced Editor?',
    'wikitext_editor' => 'Wikitext Editor?',
    'cron_schedule_interval' => 'Cron Schedule Interval',
    'sortmethod' => 'Sort Topics',
    'showstorycount' => 'Show Story Count?',
    'showsubmissioncount' => 'Show Submission Count?',
    'hide_home_link' => 'Hide Home Link?',
    'whosonline_threshold' => 'Session Threshold',
    'whosonline_anonymous' => 'Hide Names from Guests?',
    'whosonline_photo' => 'Display Thumbnail Photo?',
    'emailstories' => 'Daily Digest Enabled?',
    'emailstorieslength' => 'Length of Stories',
    'emailstoriesperdefault' => 'Enable for New Users?',
    'allow_domains' => 'Automatic Allow Domains',
    'disallow_domains' => 'Automatic Disallow Domains',
    'newstoriesinterval' => 'New Stories Interval',
    'newcommentsinterval' => 'New Comments Interval',
    'newtrackbackinterval' => 'New Trackbacks Interval',
    'hidenewstories' => 'Hide New Stories',
    'hidenewcomments' => 'Hide New Comments',
    'hidenewtrackbacks' => 'Hide New Trackbacks',
    'hidenewplugins' => 'Hide New Plugin Entries',
    'title_trim_length' => 'Title Trim Length',
    'trackback_enabled' => 'Trackback Enabled?',
    'pingback_enabled' => 'Pingback Enabled?',
    'ping_enabled' => 'Ping Enabled?',
    'trackback_code' => 'Trackback Default',
    'multiple_trackbacks' => 'Multiple Trackbacks',
    'trackbackspeedlimit' => 'Trackback Speed Limit',
    'check_trackback_link' => 'Check Trackbacks',
    'pingback_self' => 'Pingback Self?',
    'pingback_excerpt' => 'Create Pingback Excerpt?',
    'link_documentation' => 'Link to Documentation?',
    'link_versionchecker' => 'Link to Version Checker?',
    'maximagesperarticle' => 'Max Images per Article',
    'limitnews' => 'Stories per Page',
    'minnews' => 'Min. Stories per Page',
    'contributedbyline' => 'Show "Contributed By"?"',
    'hideviewscount' => 'Hide Views Count?',
    'hideemailicon' => 'Hide E-Mail Icon?',
    'hideprintericon' => 'Hide Print Icon?',
    'allow_page_breaks' => 'Allow Page Breaks?',
    'page_break_comments' => 'Comments on Multi-Page Articles',
    'article_image_align' => 'Topic Icon Alignment',
    'show_topic_icon' => 'Show Topic Icon?',
    'draft_flag' => 'Draft Flag Default',
    'frontpage' => 'Frontpage Default',
    'hide_no_news_msg' => 'Hide "No News" Message?',
    'hide_main_page_navigation' => 'Hide Main Page Navigation?',
    'onlyrootfeatures' => 'Only Root can Feature?',
    'aftersave_story' => 'After Saving Story',
    'aftersave_user' => 'After Saving User',
    'show_right_blocks' => 'Always Show Right Blocks?',
    'showfirstasfeatured' => 'Show First Story as Featured?',
    'backend' => 'Enable Feeds?',
    'rdf_file' => 'Syndication Output Folder',
    'rdf_limit' => 'Feed Limit',
    'rdf_storytext' => 'Length of Stories in Feed',
    'rdf_language' => 'Feed Language',
    'syndication_max_headlines' => 'Max. Number of Headlines (portal blocks)',
    'copyrightyear' => 'Copyright Year',
    'image_lib' => 'Image Library',
    'path_to_mogrify' => 'Path to Mogrify',
    'path_to_netpbm' => 'Path to Netpbm',
    'debug_image_upload' => 'Debug Image Uploading?',
    'keep_unscaled_image' => 'Keep Unscaled Image?',
    'allow_user_scaling' => 'Allow User Scaling?',
    'jpeg_quality' => 'JPEG Quality?',
    'max_image_width' => 'Max Image Width?',
    'max_image_height' => 'Max Image Height?',
    'max_image_size' => 'Max Image Size?',
    'max_topicicon_width' => 'Max Topic Icon Width?',
    'max_topicicon_height' => 'Max Topic Icon Height?',
    'max_topicicon_size' => 'Max Topic Icon Size?',
    'max_photo_width' => 'Max Photo Width?',
    'max_photo_height' => 'Max Photo Height?',
    'max_photo_size' => 'Max Photo Size?',
    'use_gravatar' => 'Use Gravatar?',
    'gravatar_rating' => 'Gravatar Rating',
    'force_photo_width' => 'Force Photo Width',
    'default_photo' => 'Default Photo',
    'commentspeedlimit' => 'Comment Speed Limit',
    'comment_limit' => 'Comment Limit',
    'comment_mode' => 'Comment Mode',
    'comment_code' => 'Comment Default',
    'comment_edit' => 'Allow Comment Edit?',
    'comment_edittime' => 'Comment Edit Time (seconds)',
    'commentsubmission' => 'Queue Comment Submissions',
    'passwordspeedlimit' => 'Password Speed Limit',
    'login_attempts' => 'Max. Login Attempts',
    'login_speedlimit' => 'Login Speed Limit',
    'user_html' => 'User HTML',
    'admin_html' => 'Admin HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
    'allowed_protocols' => 'Allowed Protocols',
    'disable_autolinks' => 'Disable Autotags?',
    'clickable_links' => 'Make URLs clickable?',
    'compressed_output' => 'Send compressed output?',
    'frame_options' => 'Protection against "clickjacking"',
    'censormode' => 'Censor Mode?',
    'censorreplace' => 'Censor Replace Text',
    'censorlist' => 'Censor List',
    'ip_lookup' => 'IP Lookup',
    'url_rewrite' => 'Enable URL Rewrite',
    'cdn_hosted' => 'Use CDN-hosted copy of jQuery',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Block Default Permissions',
    'default_permissions_story' => 'Story Default Permissions',
    'default_permissions_topic' => 'Topic Default Permissions',
    'atom_max_stories' => 'Max. Stories in Webservices Feed',
    'disable_webservices' => 'Disable Webservices?',
    'restrict_webservices' => 'Restrict Webservices?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Days to close comments (default)',
    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
    'allow_reply_notifications' => 'Allow comment reply notifications?',
    'search_style' => 'Results List Style',
    'search_limits' => 'Page Limits',
    'search_show_num' => 'Show Result Number?',
    'search_show_type' => 'Show Result Type?',
    'search_show_sort' => 'Allow User to Sort Results?',
    'search_show_limit' => 'Show Page Limits?',
    'search_separator' => 'Group Separator',
    'search_def_keytype' => 'Default Search Method',
    'search_def_sort' => 'Default Sort Order',
    'autotag_permissions_story' => '[story: ] Permissions',
    'autotag_permissions_user' => '[user: ] Permissions'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Site',
    'sg_stories' => 'Stories and Trackback',
    'sg_theme' => 'Theme',
    'sg_blocks' => 'Blocks',
    'sg_users' => 'Users and Submissions',
    'sg_images' => 'Images',
    'sg_locale' => 'Languages and Locale',
    'sg_misc' => 'Miscellaneous'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Site',
    'fs_paths' => 'Paths',
    'fs_theme' => 'Theme',
    'fs_mail' => 'Mail',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Users',
    'fs_misc' => 'Miscellaneous',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Block',
    'fs_locale' => 'Locale',
    'fs_language' => 'Language',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Cookies',
    'fs_login' => 'Login Settings',
    'fs_search' => 'Search',
    'fs_user_submission' => 'User Submission',
    'fs_submission' => 'Submission Settings',
    'fs_topics_block' => 'Topics Block',
    'fs_whosonline_block' => 'Who\'s Online Block',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'What\'s New Block',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Story',
    'fs_theme_advanced' => 'Advanced Settings',
    'fs_syndication' => 'Syndication',
    'fs_imagelib' => 'Image Library',
    'fs_upload' => 'Upload',
    'fs_articleimg' => 'Images in Articles',
    'fs_topicicon' => 'Topic Icons',
    'fs_userphoto' => 'Photos',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Comments',
    'fs_htmlfilter' => 'HTML Filtering',
    'fs_censoring' => 'Censoring',
    'fs_iplookup' => 'IP Lookup',
    'fs_perm_story' => 'Story Default Permission',
    'fs_perm_topic' => 'Topic Default Permission',
    'fs_perm_block' => 'Block Default Permission',
    'fs_webservices' => 'Webservices',
    'fs_autotag_permissions' => 'Autotag Usage Permissions'
);

$LANG_tab['Core'] = array(
    'tab_site' => 'Site',
    'tab_paths' => 'Paths',
    'tab_theme' => 'Theme',
    'tab_mail' => 'Mail',
    'tab_pear' => 'Pear',
    'tab_mysql' => 'MySQL',
    'tab_users' => 'Users',
    'tab_misc' => 'Miscellaneous',
    'tab_spamx' => 'Spam-X',
    'tab_admin_block' => 'Admin Block',
    'tab_locale' => 'Locale',
    'tab_language' => 'Language',
    'tab_debug' => 'Debug',
    'tab_cookies' => 'Cookies',
    'tab_login' => 'Login Settings',
    'tab_search' => 'Search',
    'tab_user_submission' => 'User Submission',
    'tab_submission' => 'Submission Settings',
    'tab_topics_block' => 'Topics Block',
    'tab_whosonline_block' => 'Who\'s Online Block',
    'tab_daily_digest' => 'Daily Digest',
    'tab_whatsnew_block' => 'What\'s New Block',
    'tab_trackback' => 'Trackback',
    'tab_pingback' => 'Pingback',
    'tab_story' => 'Story',
    'tab_theme_advanced' => 'Advanced Settings',
    'tab_syndication' => 'Syndication',
    'tab_imagelib' => 'Image Library',
    'tab_upload' => 'Upload',
    'tab_articleimg' => 'Images in Articles',
    'tab_topicicon' => 'Topic Icons',
    'tab_userphoto' => 'Photos',
    'tab_gravatar' => 'Gravatar',
    'tab_comments' => 'Comments',
    'tab_htmlfilter' => 'HTML Filtering',
    'tab_censoring' => 'Censoring',
    'tab_iplookup' => 'IP Lookup',
    'tab_permissions' => 'Permissions',
    'tab_webservices' => 'Webservices'
);

$LANG_configselects['Core'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Reject' => 0, 'Only Keep Latest' => 1, 'Allow Multiple Posts' => 2),
    3 => array('Trackback Enabled' => 0, 'Trackback Disabled' => -1),
    4 => array('Don\'t Check Anything' => 0, 'Check against Site URL' => 1, 'Check full URL' => 2, 'Check against Site URL and full URL' => 3, 'Check IP against Site IP' => 4, 'Check IP and Site URL' => 5, 'Check IP and Full URL' => 6, 'Check IP, Full URL, and Site URL' => 7),
    5 => array('Plain Old Text' => 'plaintext', 'HTML Formatted' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Last Page' => 'last', 'First Page' => 'first', 'Every Page' => 'all'),
    8 => array('Right' => 'right', 'Left' => 'left'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    10 => array('None' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Flat' => 'flat', 'Nested' => 'nested', 'Threaded' => 'threaded', 'No Comments' => 'nocomment'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
    13 => array('Skip' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
    14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
    15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
    16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
    19 => array('Google' => 'google', 'Table' => 'table'),
    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc'),
    28 => array('No access' => 0, 'Use' => 2)
);

###############################################################################
# Localization of validation error messages

$LANG_VALIDATION = array(
    'default' => 'This field contains an invalid value',
    'notEmpty' => 'This field cannot be empty',
    'alphaNumeric' => 'This field must be in alpha numeric',
    'between' => 'This field must be in specified range',
    'blank' => 'This field must be blank',
    'comparison' => 'This field does not match the comparison operation',
    'date' => 'This field must be in date format',
    'year' => 'This field must be in year format such as 2010',
    'time' => 'This field must be in time format',
    'datetime' => 'This field must be in datetime format',
    'boolean' => 'This field must be in boolean',
    'decimal' => 'This field must be in decimal',
    'email' => 'This field must contains valid email address',
    'equalTo' => 'This field does not equal',
    'extension' => 'This field only accept allowable file extension',
    'ip' => 'This field must be in valid IP format',
    'minLength' => 'This field is too short',
    'maxLength' => 'This field is too long',
    'numeric' => 'This field must be a numeric',
    'phone' => 'This field must contains valid phone number',
    'range' => 'This field must be in specified range',
    'url' => 'This field must contains valid URL',
    'inList' => 'This field must contain specified list',
    'mail_settings_backend' => 'This field must be one of \'smtp\', \'sendmail\', or \'mail\'',
    'mail_settings_sendmail_path' => 'This field must contains valid path to sendmail binary',
    'mail_settings_host' => 'This field must contain valid hostname',
    'mail_settings_port' => 'This field must be between 0 - 65535',
    'rdf_limit' => 'This field must in numeric or hour such as 24h',
    'path' => 'Path does not exist',
    'file' => 'File does not exist',
    'search_limits' => 'This field must be numeric separated with a comma',
    'num_search_results' => 'This field must be numeric and from \'search_limits\' above',
    'theme' => 'Theme directory does not exist',
    'path_themes' => 'Theme path must be in absolute path and make sure the last character contains directory separator',
    'path_to_mogrify' => 'You must set image library to imagemagick and fill this field with complete path to the mogrify executable',
    'path_to_netpbm' => 'You must set image library to netpbm and fill this field with directory where the binaries from the Netpbm package are kept',
    'language' => 'Language file does not exist',
    'timezone' => 'Invalid timezone',
    'single_char' => 'This field must be a single character'
);


?>
